/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vidur Apparao <vidur@netscape.com> (original author)
 *   Johnny Stenback <jst@netscape.com>
 *   Jonathon Jongsma <jonathon.jongsma@collabora.co.uk>, Collabora Ltd.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIDOMCSS2Properties.idl"

[scriptable, uuid(cc0a6325-770b-476d-8cb8-c2a02a43c348)]
interface nsIDOMNSCSS2Properties : nsIDOMCSS2Properties
{
           /* Non-DOM 2 extensions */

           /* Mozilla extension CSS properties */
           attribute DOMString        MozAppearance;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBackgroundClip;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBackgroundInlinePolicy;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBackgroundOrigin;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBinding;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderBottomColors;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderLeftColors;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderRightColors;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderTopColors;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderRadius;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderRadiusTopleft;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderRadiusTopright;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderRadiusBottomleft;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderRadiusBottomright;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxAlign;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxDirection;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxFlex;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxOrient;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxOrdinalGroup;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxPack;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxSizing;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnCount;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnWidth;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnGap;
                                        // raises(DOMException) on setting

           attribute DOMString        MozFloatEdge;
                                        // raises(DOMException) on setting

           attribute DOMString        MozForceBrokenImageIcon;
                                        // raises(DOMException) on setting

           attribute DOMString        MozImageRegion;
                                        // raises(DOMException) on setting

           attribute DOMString        MozMarginEnd;
                                        // raises(DOMException) on setting

           attribute DOMString        MozMarginStart;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOpacity;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutline;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineColor;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineRadius;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineRadiusTopleft;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineRadiusTopright;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineRadiusBottomleft;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineRadiusBottomright;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineStyle;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineWidth;
                                        // raises(DOMException) on setting

           attribute DOMString        MozOutlineOffset;
                                        // raises(DOMException) on setting

           attribute DOMString        MozPaddingEnd;
                                        // raises(DOMException) on setting

           attribute DOMString        MozPaddingStart;
                                        // raises(DOMException) on setting

           attribute DOMString        MozUserFocus;
                                        // raises(DOMException) on setting

           attribute DOMString        MozUserInput;
                                        // raises(DOMException) on setting

           attribute DOMString        MozUserModify;
                                        // raises(DOMException) on setting

           attribute DOMString        MozUserSelect;
                                        // raises(DOMException) on setting

           /* CSS3 properties */
           attribute DOMString        opacity;
                                        // raises(DOMException) on setting

           attribute DOMString        outlineOffset;
                                        // raises(DOMException) on setting

           /* Mozilla extensions */
           attribute DOMString        overflowX;
                                        // raises(DOMException) on setting

           attribute DOMString        overflowY;
                                        // raises(DOMException) on setting

           attribute DOMString        imeMode;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderEnd;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderEndColor;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderEndStyle;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderEndWidth;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderStart;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderStartColor;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderStartStyle;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderStartWidth;
                                        // raises(DOMException) on setting

           attribute DOMString        MozStackSizing;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBoxShadow;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBorderImage;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnRule;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnRuleWidth;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnRuleStyle;
                                        // raises(DOMException) on setting

           attribute DOMString        MozColumnRuleColor;
                                        // raises(DOMException) on setting

           attribute DOMString        wordWrap;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransform;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransformOrigin;
                                        // raises(DOMException) on setting 

           attribute DOMString        MozWindowShadow;
                                        // raises(DOMException) on setting

           attribute DOMString        MozBackgroundSize;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransitionProperty;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransitionDuration;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransitionDelay;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransitionTimingFunction;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTransition;
                                        // raises(DOMException) on setting

           attribute DOMString        pointerEvents;
                                        // raises(DOMException) on setting

           attribute DOMString        MozTabSize;
                                        // raises(DOMException) on setting
};
